Enum ssb_client::EasySsbError
[−]
[src]
pub enum EasySsbError<T> {
FailedHandshake(ClientHandshakeFailure, T),
IoError(Error, T),
}Everything that can go wrong when creating a client via easy_ssb.
Variants
FailedHandshake(ClientHandshakeFailure, T)The handshake was performed without io errors but did not terminate successfully.
IoError(Error, T)An io error happened during the handshake.